@@ -1,7 +1,7 @@
 import os
 
 
-def filter_by_file_type(directory: str, file_types: list, blacklist_mode: bool = False):
+def filter(directory: str, file_types: list, blacklist_mode: bool = False):
     """
     Filters files in a directory based on their file type
 
@@ -28,6 +28,4 @@ def filter_by_file_type(directory: str, file_types: list, blacklist_mode: bool =
 
 
 if __name__ == "__main__":
-    filter_by_file_type(
-        "C:\\Users\\ambl\\Downloads\\filter_test\\", [".png", ".txt", "md"]
-    )
+    filter("C:/Users/ambl/Downloads/filter_test/", [".png", ".txt", "md"])
